@@ -9,14 +9,20 @@ Usage::
     data: SendSSHPublicKeyResponseTypeDef = {...}
     ```
 """
+import sys
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
 
 
-__all__ = ("SendSSHPublicKeyResponseTypeDef",)
+__all__ = ("SendSSHPublicKeyResponseTypeDef", "SendSerialConsoleSSHPublicKeyResponseTypeDef")
 
 SendSSHPublicKeyResponseTypeDef = TypedDict(
     "SendSSHPublicKeyResponseTypeDef", {"RequestId": str, "Success": bool}, total=False
 )
+
+SendSerialConsoleSSHPublicKeyResponseTypeDef = TypedDict(
+    "SendSerialConsoleSSHPublicKeyResponseTypeDef", {"RequestId": str, "Success": bool}, total=False
+)
